/**	\file
*/

// Class declaration
#include "ortoolskeleton_tool.h"

//--- Registration defines
#define ORTOOLHIDESHOW__CLASS		ORTOOLHIDESHOW__CLASSNAME
#define ORTOOLHIDESHOW__LABEL		"OR - HideShow"
#define ORTOOLHIDESHOW__DESC		"OR - HideShow Tool Description"

FBToolImplementation (ORTOOLHIDESHOW__CLASS);
FBRegisterTool (ORTOOLHIDESHOW__CLASS,
				ORTOOLHIDESHOW__LABEL,
				ORTOOLHIDESHOW__DESC, 
				FB_DEFAULT_SDK_ICON);

bool ORToolHideShow::FBCreate()
{
	StartSize[0] = 160;
	StartSize[0] = 115;
	
	UICreate();
	UIConfigure();
	UIReset();

	OnShow.Add (this, (FBCallback) &ORToolHideShow::EventToolShow);
	OnShow.Add (this, (FBCallback) &ORToolHideShow::EventToolIdle);

	return true;

}
void ORToolHideShow::FBDestroy()
{
}

void ORToolHideShow::UICreate()
{
	int lS = 4;
	int lW = 100;
	int lH = 18;

	AddRegion("LabelDirections", "LabelDirections",
		lS, kFBAttachLeft, "", 1.0,
		lS, kFBAttachTop, "", 1.0,
		-lS, kFBAttachRight, "", 1.0,
		30, kFBAttachNone, NULL, 1.0);

	AddRegion("ButtonShow", "ButtonShow",
		lS, kFBAttachLeft, "", 1.0,
		lS, kFBAttachBottom, "LabelDirections", 1.0,
		lW, kFBAttachNone, NULL, 1.0,
		lH, kFBAttachNone, NULL, 1.0);

	AddRegion("ButtonHide", "ButtonHide",
		lS, kFBAttachLeft, "", 1.0,
		lS, kFBAttachBottom, "ButtonShow", 1.0,
		lW, kFBAttachNone, NULL, 1.0,
		lH, kFBAttachNone, NULL, 1.0);

	SetControl("LabelDirections", mLabelDirections);
	SetControl("ButtonShow", mButtonShow);
	SetControl("ButtonHide", mButtonHide);
}

void ORToolHideShow::UIConfigure()
{
	mLabelDirections.Caption = "Show and hide the\n"
								"selected models";
	mButtonShow.Caption = "Show Models";
	mButtonHide.Caption = "Hide Models";

	mButtonShow.OnClick.Add(this, (FBCallback) &ORToolHideShow::EventButtonShowClick);
	mButtonHide.OnClick.Add(this, (FBCallback) &ORToolHideShow::EventButtonHideClick);
}

void ORToolHideShow::UIReset()
{
}

void ORToolHideShow::EventButtonHideClick(HISender pSender, HKEvent pEvent)
{
	int i;
	FBModelList lModels;
	FBGetSelectedModels(lModels);
	for(i=0; i<lModels.GetCount();i++)
		lModels[i]->Show = false;
	lModels.Clear();
}
void ORToolHideShow::EventButtonShowClick(HISender pSender, HKEvent pEvent)
{
	int i;
	FBModelList lModels;
	FBGetSelectedModels(lModels);
	for(i=0; i<lModels.GetCount();i++)
		lModels[i]->Show = true;
	lModels.Clear();
}
void ORToolHideShow::EventToolIdle(HISender pSender, HKEvent pEvent)
{
}
void ORToolHideShow::EventToolShow(HISender pSender, HKEvent pEvent)
{
}